#
# spec file for package gnome-mahjongg
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-mahjongg
Version:        3.38.3
Release:        bp155.3.10
Summary:        Mahjong Solitaire Game for GNOME
License:        GPL-2.0-or-later
Group:          Amusements/Games/Board/Puzzle
URL:            https://live.gnome.org/GnomeMahongg
Source0:        https://download.gnome.org/sources/gnome-mahjongg/3.38/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM 26.patch -- Fix build with meson 0.60 and newer
Patch0:         https://gitlab.gnome.org/GNOME/gnome-mahjongg/-/merge_requests/26.patch

BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.24.0
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.40.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.13.2
BuildRequires:  pkgconfig(librsvg-2.0) >= 2.32.0
# Package was renamed to gnome-mahjongg, following upstreams name change during 3.6 development.
Obsoletes:      mahjongg < %{version}
Provides:       mahjongg = %{version}

%description
Mahjongg is a solitaire version of the classic Eastern tile game. It
involves clearing as much of the board as possible by matching
corresponding tiles and taking them out of play.

%lang_package

%prep
%autosetup -p1

%build
%meson \
    -Dcompile-schemas=disabled \
    -Dupdate-icon-cache=disabled
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}

%files
%license COPYING
%doc NEWS
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/metainfo/org.gnome.Mahjongg.appdata.xml
%{_datadir}/applications/org.gnome.Mahjongg.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.Mahjongg.gschema.xml
%{_datadir}/help/C/%{name}/
%{_datadir}/icons/hicolor/*/apps/org.gnome.Mahjongg*
%{_mandir}/man6/%{name}.6%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Wed Feb  2 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 26.patch: Fix build with meson 0.60 and newer.
- No longer mark enduser help files as doc.
* Mon Nov  2 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.3:
  + Enable (by default) regeneration of schema and icons.
  + Hide two unimplemented shortcuts from the help.
- Pass -Dcompile-schemas=disabled -Dupdate-icon-cache=disabled to
  meson: the glib schema and icon cache are automatically rebuilt
  when the RPM is being installed. We do not ship those caches as
  part of the package.
* Mon Oct  5 2020 dimstar@opensuse.org
- Update to version 3.38.2:
  + Fixed a regression.
  + Updated translations.
* Sat Sep 19 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.38.1:
  + Fast fix for hints.
- Changes from version 3.38.0:
  + Drawing optimizations.
  + Cleaning in scripts.
  + Updated translations.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 3.37.1:
  + Updated translations.
* Sat Apr 25 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.2:
  + help: Remove now unused localized screenshots for
    moves-left.png.
  + Updated translations.
* Sat Mar  7 2020 bjorn.lie@gmail.com
- Update to version 3.36.1:
  + Brown paper bag release, fix tags in upstream git.
* Fri Mar  6 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.0:
  + Updated translations.
* Mon Mar  2 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.35.92:
  + Avoid reloading the entire SVG theme file on each draw
    operation.
  + Updated help.
  + Updated translations.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Thu Sep 26 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.0:
  + Updated translations.
* Wed Sep  4 2019 mgorse@suse.com
- Update to version 3.33.90:
  + Updated app icon.
  + Translation updates.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
* Wed Mar  6 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.31.92:
  + Localize date column of score list.
  + Updated translations.
* Fri Feb 15 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Validate the AppStream metadata and .desktop file as build
    tests.
  + Miscellaneous cleanup.
* Tue Jan  8 2019 bjorn.lie@gmail.com
- Update to version 3.31.4:
  + Consistently use org.gnome.Mahjongg as app ID.
  + Fix pause button when clicking on game to unpause.
  + Miscellaneous improvements.
  + Updated translations.
* Sat Jan  5 2019 bjorn.lie@gmail.com
- Update to version 3.31.3:
  + Switch from autotools to meson.
  + Follow GNOME 3.32 app menu recommendations.
  + Add Keyboard Shortcuts overlay.
  + Hide Keyboard Shortcuts section in app help.
  + Add Flatpak manifest.
  + Stop using intltool.
  + Miscellaneous improvements.
- Switch to meson buildsystem, add meson BuildRequires and macros.
- Drop intltool BuildRequires, no longer needed.
- Drop post(un) handling of glib2_gsettings_schema_post(un),
  desktop_database_post(un) and icon_theme_cache_post(un) and drop
  glib2_gsettings_schema_requires, no longer needed.
- Drop update-desktop-files BuildRequires and
  suse_update_desktop_file macro, no longer needed.
- Add fdupes BuildRequires and macro, remove duplicate files.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Sep 21 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Updated translations.
* Mon Aug 15 2016 zaitor@opensuse.org
- Update to version 3.21.90:
  + Add Language headers to po files.
  + Updated translations.
* Sat May 28 2016 zaitor@opensuse.org
- Update to version 3.21.2:
  + Added educational tileset.
  + Updated translations.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + Updated translations.
* Tue Feb 16 2016 dimstar@opensuse.org
- Update to version 3.19.90:
  + Updated translations.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Fixed event propagation for gestures.
* Wed Sep  2 2015 dimstar@opensuse.org
- Update to version 3.17.91:
  + Updated translations.
* Wed May 13 2015 zaitor@opensuse.org
- Update to version 3.16.1:
  + Add symbolic icon.
- Remove HighContrast %%icon_theme_cache_post(un) calls, as Symbolic
  icons have replaced them.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Tue Mar 17 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Updated translations.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Updated translations.
* Sun Nov 30 2014 badshah400@gmail.com
- Update to version 3.15.2:
  + Increased non gnome-shell-support.
  + Updated translations.
* Mon Oct 13 2014 dimstar@opensuse.org
- Update to version 3.14.1:
  + Increased Unity and non-Gnome-environment support.
  + Updated translations.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Mon Sep 15 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Updated translations.
* Mon Sep  1 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + Fixed shuffling.
  + Updated translations.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Removed empty page in help.
  + various bugfixes and little improvements.
  + Updated translations.
* Mon Jul 21 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Added version command line option.
  + Don't show HeaderBar/app menu on systems that don't support it.
  + Appdata Changes, general fixup.
  + Updated Smooth Tileset.
  + Updated translations.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.13.1:
  + Updated documentation.
  + Updated translations.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Updated translations.
* Tue Apr 15 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Fix critical warning in Game.timeout_cb.
  + Ensure game is unpaused after Restart Game.
  + Updated translations.
* Sun Mar 23 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Wed Mar 19 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Changed default window size.
  + Updated help to reflect ui changes.
  + Updated translations.
* Mon Mar  3 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Fixed several issues with resetting and restarting the game.
  + Updated help to include bonus tiles.
  + Updated translations.
* Mon Feb 17 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Added shuffle when no more moves are left.
  + Removed toolbar in favor of GtkHeaderBar.
- Rename .desktop file to gnome-mahjongg following upstream
  changes.
* Mon Feb  3 2014 zaitor@opensuse.org
- Update to version 3.11.5:
  + Updated translations.
* Mon Jan 13 2014 dimstar@opensuse.org
- Update to version 3.11.4:
  + Flash any two matching tiles if the selected tile has no match.
  + Fix blue flower tiles in smooth tile set.
  + Remove some older tilesets.
  + update website in about dialog.
  + Updated translations.
* Mon Dec 16 2013 dimstar@opensuse.org
- Update to version 3.11.3:
  + Scores dialog: scroll to new high score.
  + Split ScoreDialog into its own file.
  + About dialog: remove period from fragment.
  + About dialog: use GtkLicense.
  + appdata: update homepage.
  + app menu: standardize Help/About/Quit.
  + Updated translations.
* Tue Nov 19 2013 dimstar@opensuse.org
- Update to version 3.11.2:
  + build: use pkg-config to find glib-compile-resources,
    add gio-2.0 to PKG_CHECK_MODULES.
  + Sort scores by duration of the game.
  + Check for *-validate before using them, run autoupdate.
  + help: Add Overpass map.
  + Updated translations.
- Add pkgconfig(gio-2.0) BuildRequies: new verified dependency.
* Sun Nov 17 2013 dimstar@opensuse.org
- Update to version 3.11.1:
  + Add Overpass map by Wa.
  + Remove deprecated function usage.
  + Help: restore note on using the Pause key.
  + Appdata is now translatable.
  + Updated translations.
* Mon Nov 11 2013 dimstar@opensuse.org
- Update to version 3.10.2 (bnc#849913):
  + Sort scores by duration of the game.
  + Updated translations.
* Mon Oct 14 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Updated translations.
* Mon Sep 23 2013 zaitor@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Mon Sep 16 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Fix Redo sometimes removing too many pieces.
  + Fix map label on scores dialog.
  + Add an appdata file.
  + Updated translations.
* Tue Aug 20 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Fix bug where the pause button could incorrectly display a
    "play" icon.
  + Fix name of application menu when not launched by GNOME Shell.
  + Fix two broken links in user help.
  + App menu now uses a UI file and is installed into a gresource.
  + Updated translations.
* Wed Mar 27 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Renamed desktop file back to mahjongg.desktop.
  + Themes from gnome-games-extra-data added.
  + High contrast icons added.
  + Updated translations.
* Tue Mar  5 2013 dimstar@opensuse.org
- Initial package, version 3.7.90: split-off from gnome-games.
